@@ -1,3 +1,3 @@
 import re
 from taf import TAF, MalformedTAF
-from tafdecoder import Decoder
+from tafdecoder import Decoder, DecodeError
